==> client-java-5.0.0-sources.jar: com/epam/reportportal/utils/properties/DefaultProperties.java <==
/*
 * Copyright 2020 EPAM Systems
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.epam.reportportal.utils.properties;

/**
 * Default implementation of {@link PropertyHolder} with attribute names that should be retrieved:
 * 1) internal - from the environment (OS, JVM)
 * 2) external - from `*.properties` file
 *
 * @author <a href="mailto:ivan_budayeu@epam.com">Ivan Budayeu</a>
 */
public enum DefaultProperties implements PropertyHolder {
	OS("os", true, "os.name", "os.arch", "os.version"),
	JVM("jvm", true, "java.vm.name", "java.version", "java.class.version"),
	AGENT("agent", false, "agent.name", "agent.version");

	private String name;
	private boolean internal;
	private String[] propertyKeys;

	DefaultProperties(String name, boolean internal, String... propertyKeys) {
		this.name = name;
		this.internal = internal;
		this.propertyKeys = propertyKeys;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public boolean isInternal() {
		return internal;
	}

	@Override
	public String[] getPropertyKeys() {
		return propertyKeys;
	}
}

==> client-java-5.0.21-sources.jar: com/epam/reportportal/utils/properties/DefaultProperties.java <==
/*
 * Copyright 2020 EPAM Systems
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.epam.reportportal.utils.properties;

/**
 * Default implementation of {@link PropertyHolder} with attribute names that should be retrieved:
 * 1) internal - from the environment (OS, JVM)
 * 2) external - from `*.properties` file
 *
 * @author <a href="mailto:ivan_budayeu@epam.com">Ivan Budayeu</a>
 */
public enum DefaultProperties implements PropertyHolder {
	OS("os", true, "os.name", "os.arch", "os.version"),
	JVM("jvm", true, "java.vm.name", "java.version", "java.class.version"),
	AGENT("agent", false, "agent.name", "agent.version");

	private final String name;
	private final boolean internal;
	private final String[] propertyKeys;

	DefaultProperties(String name, boolean internal, String... propertyKeys) {
		this.name = name;
		this.internal = internal;
		this.propertyKeys = propertyKeys;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public boolean isInternal() {
		return internal;
	}

	@Override
	public String[] getPropertyKeys() {
		return propertyKeys;
	}
}
